@@ -29,6 +29,9 @@ class Scope:
     def eval(self, s):
         return _builtin_eval(s, self.settings)
     
+    def clear(self):
+        self.settings.clear()
+    
     def __bool__(self):
         return bool(self.settings)
     
@@ -42,7 +45,7 @@ class Scope:
         return tuple(list(self))
     
     def __repr__(self):
-        return '<Scope object with value %s>' % self.settings
+        return '<Scope object at module scopeobj>'
     
     def __len__(self):
         return len(list(self))
\ No newline at end of file
